<?php

use EventPortal\Domain\Component\Option;
use EventPortal\Domain\Event\Models\Event;
use EventPortal\Domain\Field\Enums\FieldType;

return [
    'type' => Event::class,
    'label' => 'Event',
    'content' => [
        [
            'label' => 'Key details',
            'component' => FieldType::Section()->getValue(),
            'children' => [
                [
                    'component' => FieldType::TextInput()->getValue(),
                    'name' => 'name',
                    'label' => 'Event name',
                    'classes' => ['col-6'],
                    'validation' => [
                        'required',
                    ],
                    'placeholder' => 'E.g. Congress meeting',
                ],
                [
                    'component' => FieldType::TextInput()->getValue(),
                    'name' => 'url',
                    'label' => 'Url',
                    'classes' => ['col-6'],
                    'validation' => [
                        'required',
                    ],
                    'placeholder' => 'congressmeeting12',
                ],
                [
                    'component' => FieldType::Select()->getValue(),
                    'name' => 'type',
                    'label' => 'Event Type',
                    'classes' => ['col-6'],
                    'placeholder' => 'Select a event component',
                    'options' => [
                        Option::make('Single'),
                        Option::make('Seminar'),
                    ],
                    'validation' => [
                        'required',
                    ],
                ],
                [
                    'component' => FieldType::Select()->getValue(),
                    'name' => 'registration_type',
                    'label' => 'Registration Type',
                    'classes' => ['col-6'],
                    'placeholder' => 'Select a registration component',
                    'options' => [
                        Option::make('Open'),
                        Option::make('Closed'),
                    ],
                ],
                [
                    'component' => FieldType::TextInput()->getValue(),
                    'name' => 'capacity',
                    'label' => 'Capacity',
                    'placeholder' => 'E.g. 150',
                    'classes' => ['col-6'],
                ],
                [
                    'component' => FieldType::RadioButtons()->getValue(),
                    'name' => 'require_approval',
                    'label' => 'Does your event require approval?',
                    'classes' => ['col-6'],
                    'options' => [
                        Option::make('Yes')->value(true),
                        Option::make('No')->value(false),
                    ],
                ],
            ],
        ],
        [
            'component' => FieldType::Section()->getValue(),
            'label' => 'Your team',
            'children' => [
                [
                    'component' => FieldType::Select()->getValue(),
                    'name' => 'line_manager_id',
                    'label' => 'Assign a line manager',
                    'classes' => ['col-6'],
                    'placeholder' => 'Select a line manager',
                    'options' => [
                        Option::make('Toby')->value(1),
                        Option::make('Andy')->value(2),
                    ],
                ],
                [
                    'component' => FieldType::Select()->getValue(),
                    'name' => 'team_id',
                    'label' => 'Assign a team',
                    'classes' => ['col-6'],
                    'placeholder' => 'Select a team',
                    'options' => [
                        Option::make('Team One')->value(1),
                        Option::make('Team Two')->value(2),
                    ],
                ],
                [
                    'component' => FieldType::Select()->getValue(),
                    'name' => 'coordinator_id',
                    'label' => 'Assign a meeting co-oordinator',
                    'classes' => ['col-6'],
                    'placeholder' => 'Select a meeting co-ordinator',
                    'options' => [
                        Option::make('Fadhil')->value(1),
                        Option::make('Dan')->value(2),
                    ],
                ],
            ],
        ],
        [
            'label' => 'Contact details',
            'component' => FieldType::Section()->getValue(),
            'children' => [
                [
                    'component' => FieldType::TextInput()->getValue(),
                    'name' => 'phone',
                    'label' => 'Contact phone',
                    'placeholder' => 'E.g. 01010 023 445',
                    'validation' => [
                        'number',
                    ],
                ],
                [
                    'component' => FieldType::TextInput()->getValue(),
                    'name' => 'email',
                    'label' => 'Contact email',
                    'placeholder' => 'E.g. email@example.com',
                    'validation' => [
                        'email',
                    ],
                ],
            ],
        ],
        [
            'label' => 'Other Fields',
            'component' => FieldType::Section()->getValue(),
            'children' => [
                [
                    'component' => FieldType::MultiSelect()->getValue(),
                    'name' => 'multi_select',
                    'label' => 'Multiselect',
                    'classes' => ['col-6'],
                    'placeholder' => 'Select something',
                    'options' => [
                        Option::make('Toby')->value(1),
                        Option::make('Andy')->value(2),
                        Option::make('Fadhil')->value(3),
                    ],
                ],
                [
                    'component' => FieldType::RadioButtons()->getValue(),
                    'name' => 'radio_buttons',
                    'label' => 'RadioButtons Buttons',
                    'classes' => ['col-6'],
                    'placeholder' => 'Select choose',
                    'options' => [
                        Option::make('Yes'),
                        Option::make('No'),
                    ],
                ],
                [
                    'component' => FieldType::Checkbox()->getValue(),
                    'name' => 'terms_and_conditions',
                    'label' => 'Terms and conditions',
                    'classes' => ['col-6'],
                    'validation' => [
                        'required',
                    ],
                ],
                [
                    'component' => FieldType::SlideToggle()->getValue(),
                    'name' => 'slide_toggle',
                    'label' => 'Slidetoggle',
                    'classes' => ['col-6'],
                ],
                [
                    'component' => FieldType::PasswordInput()->getValue(),
                    'label' => 'Event password',
                    'name' => 'password',
                    'classes' => ['col-6'],
                    'clearable' => true,
                ],
                [
                    'component' => FieldType::TextArea()->getValue(),
                    'name' => 'description',
                    'label' => 'Event description',
                    'classes' => ['col-6'],
                ],
            ],
        ],
    ],
];
