<?php

namespace EventPortal\Domain\Component;

use EventPortal\Domain\Component\Dropdown\MultiSelect;
use EventPortal\Domain\Component\Dropdown\Select;
use EventPortal\Domain\Component\Input\PasswordInput;
use EventPortal\Domain\Component\Input\TextArea;
use EventPortal\Domain\Component\Input\TextInput;
use EventPortal\Domain\Component\Selection\Checkbox;
use EventPortal\Domain\Component\Selection\RadioButtons;
use EventPortal\Domain\Component\Selection\SlideToggle;
use EventPortal\Domain\Field\Models\Field;
use Illuminate\Support\Arr;

class MakeInput
{
    /** @var string<string> */
    public static $classes = [
        'TextInput' => TextInput::class,
        'Select' => Select::class,
        'MultiSelect' => MultiSelect::class,
        'PasswordInput' => PasswordInput::class,
        'TextArea' => TextArea::class,
        'Checkbox' => Checkbox::class,
        'RadioButtons' => RadioButtons::class,
        'SlideToggle' => SlideToggle::class,
    ];

    public static function fromField(Field $field): Component
    {
        /** @var \EventPortal\Domain\Component\Input $fullPath */
        $fullPath = Arr::get(self::$classes, $field->type->getValue());

        $component = $fullPath::make($field->label)
            ->name($field->name)
            ->placeholder($field->data->get('placeholder'))
            ->clearable($field->data->get('clearable'))
            ->classes($field->data->get('classes'))
            ->validation($field->data->get('validation'))
            ->when($field->response, function ($field, $response): void {
                $field->value($response->data->get('value'));
            });

        if ($component->hasOptions() && $field->data->get('options')) {
            $component->options($field->data->get('options'));
        }

        return $component;
    }

    public static function fromArray(array $data): Component
    {
        /** @var \EventPortal\Domain\Component\Input $fullPath */
        $fullPath = Arr::get(self::$classes, Arr::get($data, 'component'));

        $component = $fullPath::make(Arr::get($data, 'label'))
            ->name(Arr::get($data, 'name'))
            ->placeholder(Arr::get($data, 'placeholder'))
            ->clearable(Arr::get($data, 'clearable'))
            ->classes(Arr::get($data, 'classes'))
            ->validation(Arr::get($data, 'validation'));

        if (Arr::has($data, 'options')) {
            $component->options(Arr::get($data, 'options'));
        }

        return $component;
    }
}
