<?php

namespace EventPortal\Domain\Form\Factories;

use EventPortal\Contracts\HasFields;
use EventPortal\Domain\Form\Exceptions\NoDefaultFound;
use EventPortal\Domain\Form\Facades\Section;
use EventPortal\Domain\Form\Form;
use Illuminate\Support\Arr;

class FormFactory
{
    /**
     * @param string|HasFields $argument
     */
    public function make($argument): Form
    {
        if ($argument instanceof HasFields) {
            return $this->makeFromModel($argument);
        }

        return $this->makeFromDefault($argument);
    }

    public function makeFromModel(HasFields $model): Form
    {
        $model->loadMissing(['sections.children.response']);

        $sections = $model
            ->sections
            ->map(static function ($data) {
                return Section::make($data)->toArray();
            })
            ->toArray();

        return (new Form)
            ->modelClass(get_class($model))
            ->model($model)
            ->addSections($sections);
    }

    public function makeFromDefault(string $default): Form
    {
        $config = config("defaults.{$default}");

        throw_if($config === null, NoDefaultFound::class, $default);

        $sections = collect(Arr::get($config, 'content', []))
            ->map(function ($data) {
                return Section::make($data)->toArray();
            })
            ->toArray();

        return (new Form)
            ->modelClass(Arr::get($config, 'type'))
            ->addSections($sections);
    }
}
