<?php

namespace EventPortal\Http\Controllers\Auth;

use EventPortal\Http\Controllers\Controller;
use Illuminate\Http\RedirectResponse;
use Illuminate\Http\Request;
use Inertia\Inertia;
use Inertia\Response;

class LoginController extends Controller
{
    public function index(): Response
    {
        return Inertia::render('Login/Index', [
            'login' => config('auth.defaults.login'),
        ]);
    }

    public function login(Request $request): RedirectResponse
    {
        $credentials = $request->only('email', 'password');

        $request->validate([
            'email' => 'required|email',
            'password' => 'required',
        ], $credentials);

        if (auth()->attempt($credentials)) {
            return redirect()->intended(route('admin.event.index'));
        }

        return redirect()->back()->withErrors([
            'password' => 'These credentials do not match our records.',
        ]);
    }

    public function logout(): RedirectResponse
    {
        auth()->logout();

        return redirect()->route('login.index');
    }
}
