<?php

namespace EventPortal\Tests\Feature\Actions;

use EventPortal\Domain\Component\Option;
use EventPortal\Domain\Event\Models\Event;
use EventPortal\Domain\Field\Enums\FieldType;
use EventPortal\Domain\Field\Actions\InitialiseFields;
use EventPortal\Domain\Field\Models\Field;
use EventPortal\Domain\Field\Models\Section;
use EventPortal\Enums\Status;
use EventPortal\Tests\TestCase;
use Illuminate\Foundation\Testing\DatabaseMigrations;

class InitialiseFieldsTest extends TestCase
{
    use DatabaseMigrations;

    private function getData(): array
    {
        return  [
            'type' => Event::class,
            'label' => 'Event',
            'content' => [
                [
                    'label' => 'Key details',
                    'component' => FieldType::Section()->getValue(),
                    'children' => [
                        [
                            'label' => 'Event name',
                            'component' => FieldType::TextInput()->getValue(),
                        ],
                        [
                            'label' => 'Event type',
                            'component' => FieldType::Select()->getValue(),
                            'options' => [
                                Option::make('Single'),
                                Option::make('Seminar'),
                            ],
                        ],
                    ]
                ],
            ],
        ];
    }

    /** @test **/
    public function can_add_intial_fields_for_model()
    {
        /** @var InitialiseFields $action */
        $action = new InitialiseFields;

        $event = factory(Event::class)->create();

        $action->execute($this->getData()['content'], $event);

        $section = Field::first();

        $this
            ->assertDatabaseHas('events', [
                'id' => $event->id,
                'status' => Status::DRAFT(),
            ])
            ->assertDatabaseHas('fields', [
                'model_id' => $event->id,
                'model_type' => Event::class,
                'label' => 'Key details',
                'type' => 'Section',
            ])
            ->assertDatabaseHas('fields', [
                'model_id' => $event->id,
                'model_type' => Event::class,
                'section_id' => $section->id,
                'type' => 'TextInput',
                'label' => 'Event name',
                'name' => 'event_name',
            ])
            ->assertDatabaseHas('fields', [
                'model_id' => $event->id,
                'model_type' => Event::class,
                'section_id' => $section->id,
                'type' => 'Select',
                'label' => 'Event type',
                'name' => 'event_type',
            ]);
    }
}
