<?php

namespace EventPortal\Tests\Unit\Form;

use EventPortal\Domain\Event\Models\Event;
use EventPortal\Domain\Field\Enums\FieldType;
use EventPortal\Domain\Field\Models\Field;
use EventPortal\Domain\Form\Facades\Form;
use EventPortal\Tests\TestCase;
use Illuminate\Foundation\Testing\DatabaseMigrations;
use Spatie\Snapshots\MatchesSnapshots;

class FormFactoryTest extends TestCase
{
    use DatabaseMigrations, MatchesSnapshots;

    /** @test **/
    public function make_form_field()
    {
        $event = factory(Event::class)->create();

        $section = factory(Field::class)
            ->states('Section')
            ->create([
                'label' => 'Key details',
                'model_id' => $event->id,
                'model_type' => get_class($event),
            ]);

        $field = factory(Field::class)
            ->states('TextInput')
            ->create([
                'name' => 'event_name',
                'label' => 'Event Name',
                'section_id' => $section->id,
                'model_id' => $event->id,
                'model_type' => get_class($event),
            ]);

        $form = Form::make($event);

        $this->assertInstanceOf(\EventPortal\Domain\Form\Form::class, $form);
        $this->assertMatchesJsonSnapshot($form->content);
    }

    /** @test **/
    public function make_form_default()
    {
        config()->set('defaults.event', [
            'type' => Event::class,
            'label' => 'Event',
            'content' => [
                [
                    'label' => 'Key details',
                    'component' => FieldType::Section()->getValue(),
                    'children' => [
                        [
                            'component' => FieldType::TextInput()->getValue(),
                            'name' => 'name',
                            'label' => 'Event name',
                            'classes' => ['col-6'],
                            'validation' => [
                                'required',
                            ],
                            'placeholder' => 'E.g. Congress meeting',
                        ],
                    ],
                ],
            ],
        ]);

        $form = Form::make('event');

        $this->assertInstanceOf(\EventPortal\Domain\Form\Form::class, $form);
        $this->assertMatchesJsonSnapshot($form->content);
    }
}
